==> zio-aws-servicequotas_2.12-5.17.153.1-sources.jar: zio/aws/servicequotas/model/GetServiceQuotaIncreaseRequestFromTemplateResponse.scala <==
package zio.aws.servicequotas.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetServiceQuotaIncreaseRequestFromTemplateResponse(
    serviceQuotaIncreaseRequestInTemplate: Option[
      zio.aws.servicequotas.model.ServiceQuotaIncreaseRequestInTemplate
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.servicequotas.model.GetServiceQuotaIncreaseRequestFromTemplateResponse = {
    import GetServiceQuotaIncreaseRequestFromTemplateResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.servicequotas.model.GetServiceQuotaIncreaseRequestFromTemplateResponse
      .builder()
      .optionallyWith(
        serviceQuotaIncreaseRequestInTemplate.map(value =>
          value.buildAwsValue()
        )
      )(_.serviceQuotaIncreaseRequestInTemplate)
      .build()
  }
  def asReadOnly
      : zio.aws.servicequotas.model.GetServiceQuotaIncreaseRequestFromTemplateResponse.ReadOnly =
    zio.aws.servicequotas.model.GetServiceQuotaIncreaseRequestFromTemplateResponse
      .wrap(buildAwsValue())
}
object GetServiceQuotaIncreaseRequestFromTemplateResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.servicequotas.model.GetServiceQuotaIncreaseRequestFromTemplateResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.servicequotas.model.GetServiceQuotaIncreaseRequestFromTemplateResponse =
      zio.aws.servicequotas.model
        .GetServiceQuotaIncreaseRequestFromTemplateResponse(
          serviceQuotaIncreaseRequestInTemplate.map(value => value.asEditable)
        )
    def serviceQuotaIncreaseRequestInTemplate: Option[
      zio.aws.servicequotas.model.ServiceQuotaIncreaseRequestInTemplate.ReadOnly
    ]
    def getServiceQuotaIncreaseRequestInTemplate: ZIO[
      Any,
      AwsError,
      zio.aws.servicequotas.model.ServiceQuotaIncreaseRequestInTemplate.ReadOnly
    ] = AwsError.unwrapOptionField(
      "serviceQuotaIncreaseRequestInTemplate",
      serviceQuotaIncreaseRequestInTemplate
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.servicequotas.model.GetServiceQuotaIncreaseRequestFromTemplateResponse
  ) extends zio.aws.servicequotas.model.GetServiceQuotaIncreaseRequestFromTemplateResponse.ReadOnly {
    override val serviceQuotaIncreaseRequestInTemplate: Option[
      zio.aws.servicequotas.model.ServiceQuotaIncreaseRequestInTemplate.ReadOnly
    ] = scala
      .Option(impl.serviceQuotaIncreaseRequestInTemplate())
      .map(value =>
        zio.aws.servicequotas.model.ServiceQuotaIncreaseRequestInTemplate
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.servicequotas.model.GetServiceQuotaIncreaseRequestFromTemplateResponse
  ): zio.aws.servicequotas.model.GetServiceQuotaIncreaseRequestFromTemplateResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-servicequotas_2.12-5.17.257.1-sources.jar: zio/aws/servicequotas/model/GetServiceQuotaIncreaseRequestFromTemplateResponse.scala <==
package zio.aws.servicequotas.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetServiceQuotaIncreaseRequestFromTemplateResponse(
    serviceQuotaIncreaseRequestInTemplate: Optional[
      zio.aws.servicequotas.model.ServiceQuotaIncreaseRequestInTemplate
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.servicequotas.model.GetServiceQuotaIncreaseRequestFromTemplateResponse = {
    import GetServiceQuotaIncreaseRequestFromTemplateResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.servicequotas.model.GetServiceQuotaIncreaseRequestFromTemplateResponse
      .builder()
      .optionallyWith(
        serviceQuotaIncreaseRequestInTemplate.map(value =>
          value.buildAwsValue()
        )
      )(_.serviceQuotaIncreaseRequestInTemplate)
      .build()
  }
  def asReadOnly
      : zio.aws.servicequotas.model.GetServiceQuotaIncreaseRequestFromTemplateResponse.ReadOnly =
    zio.aws.servicequotas.model.GetServiceQuotaIncreaseRequestFromTemplateResponse
      .wrap(buildAwsValue())
}
object GetServiceQuotaIncreaseRequestFromTemplateResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.servicequotas.model.GetServiceQuotaIncreaseRequestFromTemplateResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.servicequotas.model.GetServiceQuotaIncreaseRequestFromTemplateResponse =
      zio.aws.servicequotas.model
        .GetServiceQuotaIncreaseRequestFromTemplateResponse(
          serviceQuotaIncreaseRequestInTemplate.map(value => value.asEditable)
        )
    def serviceQuotaIncreaseRequestInTemplate: Optional[
      zio.aws.servicequotas.model.ServiceQuotaIncreaseRequestInTemplate.ReadOnly
    ]
    def getServiceQuotaIncreaseRequestInTemplate: ZIO[
      Any,
      AwsError,
      zio.aws.servicequotas.model.ServiceQuotaIncreaseRequestInTemplate.ReadOnly
    ] = AwsError.unwrapOptionField(
      "serviceQuotaIncreaseRequestInTemplate",
      serviceQuotaIncreaseRequestInTemplate
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.servicequotas.model.GetServiceQuotaIncreaseRequestFromTemplateResponse
  ) extends zio.aws.servicequotas.model.GetServiceQuotaIncreaseRequestFromTemplateResponse.ReadOnly {
    override val serviceQuotaIncreaseRequestInTemplate: Optional[
      zio.aws.servicequotas.model.ServiceQuotaIncreaseRequestInTemplate.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.serviceQuotaIncreaseRequestInTemplate())
      .map(value =>
        zio.aws.servicequotas.model.ServiceQuotaIncreaseRequestInTemplate
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.servicequotas.model.GetServiceQuotaIncreaseRequestFromTemplateResponse
  ): zio.aws.servicequotas.model.GetServiceQuotaIncreaseRequestFromTemplateResponse.ReadOnly =
    new Wrapper(impl)
}
